@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.27.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.28.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -12,6 +12,8 @@ use Moose;
 
 use Dist::Zilla;
 
+use experimental 'postderef';
+
 with qw/
     Dist::Zilla::Role::PluginBundle::Easy
     Dist::Zilla::Role::PluginBundle::Config::Slicer
@@ -37,6 +39,33 @@ sub not_for_travis {
 
 
 
+use Type::Tiny;
+use Types::Standard qw/ Str ArrayRef /;
+
+sub version_range {
+    my( $from, $to ) = @_;
+    return join ',', grep { not $_ % 2 } $from..$to;
+}
+
+my $TravisPerlVersions = Type::Tiny->new(
+    name => 'TravisPerlVersions',
+    parent => ArrayRef,
+)->plus_coercions(
+    Str ,=> sub {
+        my $vre = qr/([\d.]+)/;
+        s/$vre\.\.$vre/version_range($1,$2)/eg;
+        return [ map { '5.' . $_ } split /\s*,\s*/, $_ ];
+    },
+);
+
+has travis_perl_versions => (
+    is => 'ro',
+    isa => $TravisPerlVersions,
+    coerce => 1,
+    default => '14..26' 
+);
+
+
 sub configure {
     my ( $self ) = @_;
     my $arg = $self->payload;
@@ -77,8 +106,10 @@ sub configure {
         not_for_travis( 'MatchManifest' ),
         qw/  ManifestSkip /,
         [ 'Git::GatherDir' => {
-                include_dotfiles => $arg->{include_dotfiles},
-              } ],
+            include_dotfiles => $arg->{include_dotfiles},
+            exclude_filename => 'cpanfile',
+        } ],
+        [ CopyFilesFromBuild => { copy => 'cpanfile' } ],
         qw/ ExecDir
           PkgVersion /,
           [ Authority => { 
@@ -95,12 +126,20 @@ sub configure {
           TestRelease
           ConfirmRelease
           Git::Check
+          CopyrightYearFromGit
           /,
         [ 'Git::CommitBuild' => { 
                 release_branch => $release_branch ,
                 multiple_inheritance => 1,
         } ],
         [ 'Git::Tag'  => { tag_format => 'v%v', branch => $release_branch } ],
+        [ TravisCI => [
+            verbose => 0,
+            install => 'cpanm --installdeps -n .',
+            script => 'prove -l t',
+            
+            map { ( perl_version => $_ ) } $self->travis_perl_versions->@*
+        ]  ]
     );
 
     # Git::Commit can't be before Git::CommitBuild :-/
@@ -186,7 +225,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.27.0
+version 0.28.0
 
 =head1 DESCRIPTION
 
@@ -230,6 +269,12 @@ his distributions. It's roughly equivalent to
     [ManifestSkip]
 
     [Git::GatherDir]
+    exclude_filename = cpanfile
+
+    [CopyFilesFromBuild]
+    copy = cpanfile
+
+
     [ExecDir]
 
     [PkgVersion]
@@ -280,8 +325,13 @@ his distributions. It's roughly equivalent to
     [DOAP]
     process_changes = 1
 
+    [TravisCI]
+    verbose = 0
+
     [CPANFile]
 
+    [CopyrightYearFromGit]
+
 =head2 ARGUMENTS
 
 =head3 autoprereqs_skip
@@ -342,13 +392,23 @@ The name of the upstream repo.
 
 Defaults to C<github>.
 
+=head3 travis_perl_versions
+
+    travis_perl_versions = 14,16,18,20,22,24,26
+
+Comma-separated list of perl versions (without the leading '5') that
+travis should test. Ranges can be given (C<14..16>), for which the
+odd numbers will be skipped. So C<14..26> will result in C<14,16,18,...>.
+
+Defaults to C<14..26>.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yanick Champoux.
+This software is copyright (c) 2017, 2015, 2014, 2013, 2012, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
